==> qtjambi-bluetooth-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiBluetooth/QBluetoothTransferRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothtransferrequest.h>
#include <QtCore/QVariant>
#include <QtBluetooth/qbluetoothaddress.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothTransferRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothTransferRequest")
    QBluetoothTransferRequest *_ptr = reinterpret_cast<QBluetoothTransferRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBluetoothTransferRequest(QBluetoothAddress)
void __qt_construct_QBluetoothTransferRequest_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothAddress)")
    Q_UNUSED(__java_arguments)
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QBluetoothTransferRequest(QBluetoothAddress)
void __qt_construct_QBluetoothTransferRequest_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothAddress)")
    jobject address0 = __java_arguments[0].l;
    const QBluetoothAddress& __qt_address0 = qtjambi_cast<const QBluetoothAddress& >(__jni_env, address0);
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest(__qt_address0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QBluetoothTransferRequest(QBluetoothTransferRequest)
void __qt_construct_QBluetoothTransferRequest_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothTransferRequest)")
    jobject other0 = __java_arguments[0].l;
    const QBluetoothTransferRequest& __qt_other0 = qtjambi_cast<const QBluetoothTransferRequest& >(__jni_env, other0);
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QBluetoothTransferRequest
void __qt_destruct_QBluetoothTransferRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothTransferRequest")
    reinterpret_cast<QBluetoothTransferRequest*>(ptr)->~QBluetoothTransferRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothAddress)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_initialize_1native__Lio_qt_bluetooth_QBluetoothTransferRequest_2Lio_qt_bluetooth_QBluetoothAddress_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject address0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothAddress)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = address0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothTransferRequest_1, sizeof(QBluetoothTransferRequest), typeid(QBluetoothTransferRequest), false, &deleter_QBluetoothTransferRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothTransferRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_initialize_1native__Lio_qt_bluetooth_QBluetoothTransferRequest_2Lio_qt_bluetooth_QBluetoothTransferRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothTransferRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothTransferRequest_2, sizeof(QBluetoothTransferRequest), typeid(QBluetoothTransferRequest), false, &deleter_QBluetoothTransferRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothTransferRequest::address()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_address_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::address()const", __qt_this)
        QBluetoothAddress __qt_return_value = __qt_this->address();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::attribute(QBluetoothTransferRequest::Attribute,QVariant)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_attribute_1native_1QBluetoothTransferRequest_1Attribute_1cref_1QVariant_1constfct__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0,
 jobject defaultValue1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::attribute(QBluetoothTransferRequest::Attribute,QVariant)const", __qt_this)
        QBluetoothTransferRequest::Attribute __qt_code0 = qtjambi_cast<QBluetoothTransferRequest::Attribute>(__jni_env, code0);
        QVariant  __qt_defaultValue1 = qtjambi_cast<QVariant >(__jni_env, defaultValue1);
        QVariant __qt_return_value = __qt_this->attribute(QBluetoothTransferRequest::Attribute(__qt_code0), __qt_defaultValue1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::operator=(QBluetoothTransferRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_assign_1native_1cref_1QBluetoothTransferRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::operator=(QBluetoothTransferRequest)", __qt_this)
        const QBluetoothTransferRequest& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothTransferRequest>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothTransferRequest::operator==(QBluetoothTransferRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_operator_1equal_1native_1cref_1QBluetoothTransferRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::operator==(QBluetoothTransferRequest)const", __qt_this)
        const QBluetoothTransferRequest& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothTransferRequest>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::setAttribute(QBluetoothTransferRequest::Attribute,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_setAttribute_1native_1QBluetoothTransferRequest_1Attribute_1cref_1QVariant__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0,
 jobject value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::setAttribute(QBluetoothTransferRequest::Attribute,QVariant)", __qt_this)
        QBluetoothTransferRequest::Attribute __qt_code0 = qtjambi_cast<QBluetoothTransferRequest::Attribute>(__jni_env, code0);
        QVariant  __qt_value1 = qtjambi_cast<QVariant >(__jni_env, value1);
        __qt_this->setAttribute(QBluetoothTransferRequest::Attribute(__qt_code0), __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothTransferRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothTransferRequest>("QBluetoothTransferRequest", "io/qt/bluetooth/QBluetoothTransferRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothTransferRequest, {
        ConstructorInfo(&__qt_construct_QBluetoothTransferRequest_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothTransferRequest_1, "Lio/qt/bluetooth/QBluetoothAddress;")
       ,ConstructorInfo(&__qt_construct_QBluetoothTransferRequest_2, "Lio/qt/bluetooth/QBluetoothTransferRequest;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothTransferRequest);
    registerMetaType<QBluetoothTransferRequest>("QBluetoothTransferRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QBluetoothTransferRequest::Attribute>("QBluetoothTransferRequest::Attribute", "io/qt/bluetooth/QBluetoothTransferRequest$Attribute");
// END: enums and flags
}

==> qtjambi-bluetooth-debuginfo-linux-x64-5.15.19.jar: sources/QtJambiBluetooth/QBluetoothTransferRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothtransferrequest.h>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothTransferRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothTransferRequest")
    QBluetoothTransferRequest *_ptr = reinterpret_cast<QBluetoothTransferRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBluetoothTransferRequest(QBluetoothAddress)
void __qt_construct_QBluetoothTransferRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothAddress)")
    Q_UNUSED(__java_arguments)
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QBluetoothTransferRequest(QBluetoothAddress)
void __qt_construct_QBluetoothTransferRequest_cref_QBluetoothAddress(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothAddress)")
    jobject address0 = __java_arguments[0].l;
    const QBluetoothAddress& __qt_address0 = qtjambi_cast<const QBluetoothAddress& >(__jni_env, address0);
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest(__qt_address0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothAddress)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_initialize_1native__Lio_qt_bluetooth_QBluetoothTransferRequest_2Lio_qt_bluetooth_QBluetoothAddress_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject address0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothAddress)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = address0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothTransferRequest_cref_QBluetoothAddress, sizeof(QBluetoothTransferRequest), typeid(QBluetoothTransferRequest), false, &deleter_QBluetoothTransferRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBluetoothTransferRequest(QBluetoothTransferRequest)
void __qt_construct_QBluetoothTransferRequest_cref_QBluetoothTransferRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothTransferRequest(QBluetoothTransferRequest)")
    jobject other0 = __java_arguments[0].l;
    const QBluetoothTransferRequest& __qt_other0 = qtjambi_cast<const QBluetoothTransferRequest& >(__jni_env, other0);
    QBluetoothTransferRequest *__qt_this = new(__qtjambi_ptr) QBluetoothTransferRequest(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothTransferRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_initialize_1native__Lio_qt_bluetooth_QBluetoothTransferRequest_2Lio_qt_bluetooth_QBluetoothTransferRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothTransferRequest::QBluetoothTransferRequest(QBluetoothTransferRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothTransferRequest_cref_QBluetoothTransferRequest, sizeof(QBluetoothTransferRequest), typeid(QBluetoothTransferRequest), false, &deleter_QBluetoothTransferRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBluetoothTransferRequest
void __qt_destruct_QBluetoothTransferRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothTransferRequest")
    reinterpret_cast<QBluetoothTransferRequest*>(ptr)->~QBluetoothTransferRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothTransferRequest::address()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_address_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::address()const", __qt_this)
        QBluetoothAddress __qt_return_value = __qt_this->address();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::attribute(QBluetoothTransferRequest::Attribute,QVariant)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_attribute_1native_1QBluetoothTransferRequest_1Attribute_1cref_1QVariant_1constfct__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0,
 jobject defaultValue1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::attribute(QBluetoothTransferRequest::Attribute,QVariant)const", __qt_this)
        QBluetoothTransferRequest::Attribute __qt_code0 = qtjambi_cast<QBluetoothTransferRequest::Attribute>(__jni_env, code0);
        QVariant  __qt_defaultValue1 = qtjambi_cast<QVariant >(__jni_env, defaultValue1);
        QVariant __qt_return_value = __qt_this->attribute(QBluetoothTransferRequest::Attribute(__qt_code0), __qt_defaultValue1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::operator=(QBluetoothTransferRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_assign_1native_1cref_1QBluetoothTransferRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::operator=(QBluetoothTransferRequest)", __qt_this)
        const QBluetoothTransferRequest& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothTransferRequest>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothTransferRequest::operator==(QBluetoothTransferRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_equals_1native_1cref_1QBluetoothTransferRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::operator==(QBluetoothTransferRequest)const", __qt_this)
        const QBluetoothTransferRequest& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothTransferRequest>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothTransferRequest::setAttribute(QBluetoothTransferRequest::Attribute,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_setAttribute_1native_1QBluetoothTransferRequest_1Attribute_1cref_1QVariant__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0,
 jobject value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothTransferRequest::setAttribute(QBluetoothTransferRequest::Attribute,QVariant)", __qt_this)
        QBluetoothTransferRequest::Attribute __qt_code0 = qtjambi_cast<QBluetoothTransferRequest::Attribute>(__jni_env, code0);
        QVariant  __qt_value1 = qtjambi_cast<QVariant >(__jni_env, value1);
        __qt_this->setAttribute(QBluetoothTransferRequest::Attribute(__qt_code0), __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothTransferRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothTransferRequest *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothTransferRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothTransferRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothTransferRequest>("QBluetoothTransferRequest", "io/qt/bluetooth/QBluetoothTransferRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothTransferRequest, {
        ConstructorInfo(&__qt_construct_QBluetoothTransferRequest, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothTransferRequest_cref_QBluetoothAddress, "Lio/qt/bluetooth/QBluetoothAddress;")
       ,ConstructorInfo(&__qt_construct_QBluetoothTransferRequest_cref_QBluetoothTransferRequest, "Lio/qt/bluetooth/QBluetoothTransferRequest;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothTransferRequest);
    registerMetaType<QBluetoothTransferRequest>("QBluetoothTransferRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QBluetoothTransferRequest::Attribute>("QBluetoothTransferRequest::Attribute", "io/qt/bluetooth/QBluetoothTransferRequest$Attribute");
// END: enums and flags
}
